import { APIGatewayProxyEventV2, APIGatewayProxyStructuredResultV2 } from 'aws-lambda/trigger/api-gateway-proxy';
import { Context } from 'aws-lambda/handler';
import Log from 'lambda-tree';
import { JSONSchemaType } from 'ajv';
export declare enum HttpStatus {
    OK = 200,
    Created = 201,
    Accepted = 202,
    NoContent = 204,
    BadRequest = 400,
    Unauthorized = 401,
    Forbidden = 403,
    NotFound = 404,
    MethodNotAllowed = 405,
    Conflict = 409,
    InternalServerError = 500,
    NotImplemented = 501,
    BadGateway = 502,
    ServiceUnavailable = 503,
    GatewayTimeout = 504
}
export declare type LoadIdentity<TEvent, TAppIdentity> = ((event: TEvent, context: Context) => Promise<TAppIdentity>) | undefined;
export interface ApplicationInitOptions<TEvent, TAppIdentity, TCustomOptions, TSchemaType> {
    /**
     * authorize the user when they init, DEFAULT is true
     */
    authorize: boolean;
    accessControlAllowOrigin: string;
    schema: JSONSchemaType<TSchemaType> | undefined;
    require: {
        headers?: string[];
        parameters?: {
            path?: string[];
            querystring?: string[];
        };
    };
    custom: TCustomOptions;
    onAuthorize?: LoadIdentity<TEvent, TAppIdentity>;
    onResponse?: (result: APIGatewayProxyStructuredResultV2) => void;
}
export interface ApplicationInitRequest<TEvent, TAppIdentity, TCustomOptions, TSchemaType> {
    event: TEvent;
    context: Context;
    options?: Partial<ApplicationInitOptions<TEvent, TAppIdentity, TCustomOptions, TSchemaType>>;
}
export interface AppContext {
    awsRequestId: string;
    requestId: string;
    userAgent: string;
    sourceIp: string;
}
export interface AppRequest<TEvent> {
    event: TEvent | undefined;
    context: Context | undefined;
    headers: Record<string, string | undefined>;
    parameters: {
        path: Record<string, string | undefined>;
        querystring: Record<string, string | undefined>;
    };
}
export declare class LambdaAppError<TEvent extends APIGatewayProxyEventV2 = APIGatewayProxyEventV2, TAppIdentity = never, TCustomOptions extends object = never, TSchemaType = never> extends Error {
    private _app;
    private _statusCode;
    get app(): LambdaApp<TEvent, TAppIdentity, TCustomOptions, TSchemaType> | undefined;
    get response(): APIGatewayProxyStructuredResultV2 | undefined;
    constructor(app: LambdaApp<TEvent, TAppIdentity, TCustomOptions, TSchemaType>, message: string, statusCode: HttpStatus);
}
export default class LambdaApp<TEvent extends APIGatewayProxyEventV2 = APIGatewayProxyEventV2, TAppIdentity = never, TCustomOptions extends object = never, TSchemaType = never> {
    private _request;
    private _options;
    private _log;
    private _requestId;
    private _identity;
    private _startTime;
    get request(): AppRequest<TEvent>;
    get log(): Log<object>;
    get identity(): TAppIdentity;
    get awsRequestId(): string;
    get requestId(): string;
    set requestId(v: string);
    get userAgent(): string;
    get sourceIp(): string;
    get duration(): number;
    private getDefaultInitOptions;
    get options(): ApplicationInitOptions<TEvent, TAppIdentity, TCustomOptions, TSchemaType>;
    getBody<T = never>(): Promise<T>;
    /**
     * @throws LambdaAppError
     * @param param0 {event, context, options}
     * @returns
     */
    init({ event, context, options }: ApplicationInitRequest<TEvent, TAppIdentity, TCustomOptions, TSchemaType>): Promise<LambdaApp<TEvent, TAppIdentity, TCustomOptions, TSchemaType>>;
    private jsonResponse;
    response(httpStatus: HttpStatus, json?: Record<string, unknown>): APIGatewayProxyStructuredResultV2;
}
